@@ -12,6 +12,7 @@ from ..routing import APIRouter, EndpointDefinition
 
 
 class SwaggerGenerator(Blueprint):
+    """Swagger Spec Generator"""
     def __init__(
         self,
         title: str = "Auto Swagger",
@@ -186,6 +187,7 @@ class SwaggerGenerator(Blueprint):
         return "string"
 
 class AutoSwagger(SwaggerGenerator):
+    """Swagger Generator Blueprints to allow automatic documentation for flask's view functions"""
     def __init__(
         self,
         title: str = "Auto Swagger",
